@@ -460,14 +460,14 @@ class PageOrganiser(object):
         return sns_wrapper
 
 
-for dir in dirs:
-    print(f"Compiling {dir}")
-    fullpath = Path("/home/alan/Documents/dev/skeletons/data/") / dir / dir
-    compiler = ExperimentCompiler(None, fullpath)
-    tmp = compiler.run()
-    po = PageOrganiser(tmp, grid_spec=(3, 2))
-    po.plot()
-    po.save(fullpath / f"{dir.rstrip('/')}_report.pdf")
+# for dir in dirs:
+#     print(f"Compiling {dir}")
+#     fullpath = Path("/home/alan/Documents/dev/skeletons/data/") / dir / dir
+#     compiler = ExperimentCompiler(None, fullpath)
+#     tmp = compiler.run()
+#     po = PageOrganiser(tmp, grid_spec=(3, 2))
+#     po.plot()
+#     po.save(fullpath / f"{dir.rstrip('/')}_report.pdf")
 
 #### Live editing
 
