@@ -1,6 +1,6 @@
 import pandas as pd
 
-from agora.base import ParametersABC, ProcessABC
+from agora.abc import ParametersABC, ProcessABC
 
 
 class dsignalParameters(ParametersABC):
